==> viha-5.15.tar.gz: viha-5.15/laite-oper.php <==
<?php

# Copyright (C) 2009 Riku Kalinen
# License conditions in the file lisenssi.html
# Lisenssiehdot tiedostossa lisenssi.html

$table = "laite";
$file = basename(__FILE__);

include "common.php";

function laske_laitteet_jarjesto_hlo($j_id, $h_id) {
  global $prefix;
  
  return
    ota_yksi("SELECT COUNT(*)
              FROM laite
              WHERE jarjesto_id = $j_id AND hlo_id = $h_id
              AND (alue_id = 2 OR alue_id = " . s("alue") . ")");
}

function laske_tavarat_jarjesto_hlo($j_id, $h_id) {
  global $prefix;
  
  return
    ota_yksi("SELECT COUNT(*)
              FROM tavara
              WHERE jarjesto_id = $j_id AND hlo_id = $h_id
              AND (alue_id = 2 OR alue_id = " . s("alue") . ")");
}

function laske_releet_jarjesto_hlo($j_id, $h_id) {
  return
    laske_laitteet_jarjesto_hlo($j_id, $h_id) +
    laske_tavarat_jarjesto_hlo($j_id, $h_id);
}

function nayta_releet_jarjesto_hlo($j_id, $h_id) {
  global $prefix;
  
  echo "<TR><TD><TD>"
    . ota_yksi_0("SELECT nimi FROM hlo WHERE id = $h_id",
		 $h_id, "EI YHDYSHENKIL")
    . "\n";
  $sql =
    "SELECT id,laite,tunniste,alue_id,paivystys_id
     FROM laite
     WHERE jarjesto_id = $j_id AND hlo_id = $h_id
           AND (alue_id = 2 OR alue_id = " . s("alue") . ")
     ORDER BY laite, tunniste";
  $handle = my_mysql_query($sql);
  while ($a = mysql_fetch_array($handle)) {
    $take_ok = 1;
    if ($a['paivystys_id'] == s('paivystys'))
      $take_ok = 0;
    echo "<TR><TD><TD><TD>$a[laite]<TD>$a[tunniste]"
      . "<TD>" . nayta_operaatio($a['paivystys_id']);
    if ($take_ok) {
      echo "<TD><a href=\"$file?id=$a[id]&take=LAITE\">OTA TM</a>";
    } else {
      echo "<TD><a href=\"$file?id=$a[id]&release=LAITE\">VAPAUTA TM</a>";
    }
    echo "\n";
  }
  $sql =
    "SELECT id,tavara,tunniste,alue_id,paivystys_id
     FROM tavara
     WHERE jarjesto_id = $j_id AND hlo_id = $h_id
           AND (alue_id = 2 OR alue_id = " . s("alue") . ")
     ORDER BY tavara, tunniste";
  $handle = my_mysql_query($sql);
  while ($a = mysql_fetch_array($handle)) {
    $take_ok = 1; 
    if ($a['paivystys_id'] == s('paivystys'))
      $take_ok = 0;
    echo "<TR><TD><TD><TD>$a[tavara]<TD>$a[tunniste]"
      . "<TD>" . nayta_operaatio($a['paivystys_id']);
    if ($take_ok) {
      echo "<TD><a href=\"$file?id=$a[id]&take=TAVARA\">OTA TM</a>";
    } else {
      echo "<TD><a href=\"$file?id=$a[id]&release=TAVARA\">VAPAUTA TM</a>";
    }
    echo "\n";
  }
}

function nayta_releet_jarjesto($j_id,$j_jarjesto) {
  global $prefix;

  $j_n =
    ota_yksi("
SELECT COUNT(*)
FROM laite
WHERE jarjesto_id = $j_id
      AND (alue_id = 2 OR alue_id = " . s("alue") . ")
") + 
    ota_yksi("
SELECT COUNT(*)
FROM tavara
WHERE jarjesto_id = $j_id
      AND (alue_id = 2 OR alue_id = " . s("alue") . ")
");
  if ($j_n > 0) {
    # jrjestll on kamaa, nytetn.
    echo tr_bgcolor()
      . "<TD>$j_jarjesto";
    if ($j_id > 2) {
      echo "<TD><TD><TD><TD>"
	. "<TD><a href=\"$file?id=$j_id&take=JARJESTO\">OTA KAIKKI</a>"
	. "<br><a href=\"$file?id=$j_id&release=JARJESTO\">VAPAUTA KAIKKI</a>";
    }
    echo "\n";
    # ensin anonyymit releet 
    if (laske_releet_jarjesto_hlo($j_id, 0) > 0) {
      nayta_releet_jarjesto_hlo($j_id, 0);
    }
    # ... ja sitten vastuuhenkilittin
    $sql_h = "SELECT id,nimi FROM hlo ORDER BY nimi";
    $handle_h = my_mysql_query($sql_h);
    while ($h =  mysql_fetch_array($handle_h)) {
      $h_id = $h['id'];
      if (laske_releet_jarjesto_hlo($j_id, $h_id) > 0) {
	nayta_releet_jarjesto_hlo($j_id, $h_id);
      }
    }    
  }
}

echo "
<html>
<head>
 <title>ViHa - Operaation varustaminen</title>
</head>
" . body_bgcolor() . "
<h1>" . ota_paivystys_nimi() . ", operaation varustaminen</h1>
";

taktiset_linkit();

$id = get_nro_0('id');

# parametrointi toimii eri tavalla kuin yleens.
# take = ota, joka voi olla LAITE, TAVARA, HLO tai JARJESTO sen mukaan,
# halutaanko ottaa yksittinen laite tai tavara, kaikki tietyn yhdyshenkiln
# takana olevat laitteet ja tavarat vai kaikki koko jrjestn laitteet ja
# tavarat.
# release = vapauta toimii vastaavasti.

# show voi olla joko JARJESTO tai '', jolloin vastaavasti nytetn
# vain tietyn jrjestn (jarjesto_id) tai kaikki kalusto. XXX ei tehty viel

$take = get_txt('take');
$release = get_txt('release');
$show = get_nro('show');

$paivystys_se = s('paivystys');

# kuka vaan voi ottaa kalustoa alueeltaan - kytettvyyskysymys
switch ($take) {
 case '':
   break;
 case "LAITE":
   oltava_alueella($file,"laite",$id);
   break;
 case "TAVARA":
   oltava_alueella($file,"tavara",$id);
   break;
 case "JARJESTO":
   oltava_alueella($file,"jarjesto",$id);
   break;
 default:
   die("<p>Tuntematon parametri take=$take\n");
 }

if ($take == 'LAITE') {
  $p_id = ota_yksi("SELECT paivystys_id FROM laite WHERE id = $id");
  if ($p_id != $paivystys_se) {
    ilmoita_laite_jos_tarpeen($id);
    $now = date('Y-m-d H:i:s');
    $sql = "
UPDATE laite
SET paivystys_id=$paivystys_se, ryhma_id=1, ts='$now'
WHERE id=$id";
    $result = my_mysql_query ($sql,true,true);
    echo "<p>Viestivline otettu thn operaatioon.\n";
    taktinen_loki("Otettu viestivline " . laite_tunniste($id));
  } else {
    echo "<p>Et voi ottaa viestivlinett joka kuuluu jo thn operaatioon.";
  }
}

if ($take == 'TAVARA') {
  $p_id = ota_yksi("SELECT paivystys_id FROM tavara WHERE id = $id");
  if ($p_id != $paivystys_se) {
    ilmoita_laite_jos_tarpeen($id);
    $now = date('Y-m-d H:i:s');
    $sql = "
UPDATE tavara
SET paivystys_id=$paivystys_se, ryhma_id=1, ts='$now'
WHERE id=$id";
    $result = my_mysql_query ($sql,true,true);
    echo "<p>Tavara otettu thn operaatioon.\n";
    taktinen_loki("Otettu tavara " . tavara_tunniste($id));
  } else {
    echo "<p>Et voi ottaa tavaraa joka kuuluu jo thn operaatioon.";
  }
}

if ($take == 'HLO') {
  die("<p>Nothing Happens."); # XXX
}

if ($take == 'JARJESTO') {
  $now = date('Y-m-d H:i:s');
  $sql =
    "UPDATE laite
     SET paivystys_id=$paivystys_se, ryhma_id=1, ts='$now'
     WHERE jarjesto_id=$id";
  $result = my_mysql_query ($sql,true,true);
  $sql =
    "UPDATE tavara
     SET paivystys_id=$paivystys_se, ryhma_id=1, ts='$now'
     WHERE jarjesto_id=$id";
  $result = my_mysql_query ($sql,true,true);
  echo "<p>Jrjestn koko kalusto otettu thn operaatioon.\n";
  taktinen_loki("Otettu jrjestn " . jarjesto($id)
		. " kaikki kalusto thn operaatioon.");
}

if ($release == 'LAITE') {
  $p_id = ota_yksi("SELECT paivystys_id FROM laite WHERE id = $id");
  if ($p_id == $paivystys_se) {
    $now = date('Y-m-d H:i:s');
    $sql = "
UPDATE laite
SET paivystys_id=1, ryhma_id=1, ts='$now'
WHERE id=$id";
    $result = my_mysql_query ($sql);
    echo "<p>Viestivline vapautettu.\n";
    loki($sql);
    taktinen_loki("Vapautettu viestivline " . laite_tunniste($id));
  } else {
    echo
      "<p>Et voi vapauttaa viestivlinett joka ei kuulu thn operaatioon.";
  }
}

if ($release == 'TAVARA') {
  $p_id = ota_yksi("SELECT paivystys_id FROM tavara WHERE id = $id");
  if ($p_id == $paivystys_se) {
    $now = date('Y-m-d H:i:s');
    $sql =
      "UPDATE tavara
       SET paivystys_id=1, ryhma_id=1, ts='$now'
       WHERE id=$id";
    $result = my_mysql_query ($sql);
    echo "<p>Tavara vapautettu.\n";
    loki($sql);
    taktinen_loki("Vapautettu tavara " . tavara_tunniste($id));
  } else {
    echo
      "<p>Et voi vapauttaa kalustoa joka ei kuulu thn operaatioon.";
  }
}

if ($release == 'JARJESTO') {
  $now = date('Y-m-d H:i:s');
  $sql = "
UPDATE laite
SET paivystys_id=1, ryhma_id=1, ts='$now'
WHERE jarjesto_id=$id";
  $result = my_mysql_query ($sql,true,true);
  $sql = "
UPDATE tavara
SET paivystys_id=1, ryhma_id=1, ts='$now'
WHERE jarjesto_id=$id";
  $result = my_mysql_query ($sql,true,true);
  echo "<p>Jrjestn koko kalusto vapautettu.\n";
  taktinen_loki("Vapautettu jrjestn " . jarjesto($id)
		. " kaikki kalusto.");
}

# nytt generoidaan jrjestittin ja yhdyshenkilittin.

echo "<form action=\"\" method=\"GET\">\n";

echo "<input type=\"hidden\" name=\"id\" size=8 maxlength=8";
echo " value=\"$id\">\n";

echo "<p><TABLE BORDER=1>\n";
echo tr_bgcolor()
     . "<TH>Jrjest<TH>Yhdyshenkil<TH>Viestivline<BR>Tavara<TH>Tunniste"
     . "<TH>Operaatio\n";
$sql_j = "SELECT id,jarjesto,alue_id FROM jarjesto ORDER BY jarjesto";
$handle_j = my_mysql_query($sql_j);
while ($j =  mysql_fetch_array($handle_j)) {
  if (alue_nakyy($j['alue_id']))
    nayta_releet_jarjesto($j['id'],$j['jarjesto']);
}
echo "</TABLE>";

echo "</form>\n";

echo "
<p>Voit ottaa kalustoa tmn operaation kyttn klikkaamalla kohtaa OTA TM
(toimii mys muihin operaatioihin merkittyyn kalustoon).
<p>Kalustoa vapautetaan tmn operaation kytst klikkaamalla VAPAUTA TM.
Et voi vapauttaa kalustoa, joka ei kuulu thn operaatioon.
<p>Jrjestjen kohdalla olevat OTA KAIKKI ja VAPAUTA KAIKKI - linkit ottavat
ja vapauttavat koko jrjestn kaluston.
<p>Operaatio-sarakkeessa <font color=red>punaisella</font> on merkitty muut
operaatiot. Tmn operaation kalusto on merkitty
<font color=green>vihrell</font>. Vapaat on merkitty tll vrill.
";

#echo "
#<ul>Vaihtoehtoisia nkymi thn sivuun
#<li><a href=\"$file?show=\">
#  Nyt kaikki
# </a> (oletus)
#<li><a href=\"$file?show=1\">
#  Nyt vain henkilt jotka ovat vapaita tai toisessa operaatiossa
# </a> (kaikki otettavissa olevat)
#<li><a href=\"$file?show=2\">
#  Nyt vain henkilt jotka ovat vapaita
# </a>
#<li><a href=\"$file?show=3\">
#  Nyt vain henkilt jotka ovat tss operaatiossa
# </a> (kaikki vapautettavissa olevat)
#</ul>";

loppu();

?>
</body> 
</html>
<!-- RCS $Id: laite-oper.php,v 1.25 2009/04/20 10:49:38 riku Exp $ -->

==> viha-5.27.tar.gz: viha-5.27/laite-oper.php <==
<?php

# Copyright (C) 2009 Riku Kalinen
# License conditions in the file lisenssi.html
# Lisenssiehdot tiedostossa lisenssi.html

$table = "laite";
$file = basename(__FILE__);

include "common.php";

function laske_laitteet_jarjesto_hlo($j_id, $h_id) {
  global $prefix;
  
  return
    ota_yksi("SELECT COUNT(*)
              FROM laite
              WHERE jarjesto_id = $j_id AND hlo_id = $h_id
              AND (alue_id = 2 OR alue_id = " . s("alue") . ")");
}

function laske_tavarat_jarjesto_hlo($j_id, $h_id) {
  global $prefix;
  
  return
    ota_yksi("SELECT COUNT(*)
              FROM tavara
              WHERE jarjesto_id = $j_id AND hlo_id = $h_id
              AND (alue_id = 2 OR alue_id = " . s("alue") . ")");
}

function laske_releet_jarjesto_hlo($j_id, $h_id) {
  return
    laske_laitteet_jarjesto_hlo($j_id, $h_id) +
    laske_tavarat_jarjesto_hlo($j_id, $h_id);
}

function nayta_releet_jarjesto_hlo($j_id, $h_id) {
  global $prefix;
  
  echo "<TR><TD><TD>"
    . ota_yksi_0("SELECT nimi FROM hlo WHERE id = $h_id",
		 $h_id, "EI YHDYSHENKIL")
    . "\n";
  $sql =
    "SELECT id,laite,tunniste,alue_id,paivystys_id
     FROM laite
     WHERE jarjesto_id = $j_id AND hlo_id = $h_id
           AND (alue_id = 2 OR alue_id = " . s("alue") . ")
     ORDER BY laite, tunniste";
  $handle = my_mysql_query($sql);
  while ($a = mysql_fetch_array($handle)) {
    $take_ok = 1;
    if ($a['paivystys_id'] == s('paivystys'))
      $take_ok = 0;
    echo "<TR><TD><TD><TD>$a[laite]<TD>$a[tunniste]"
      . "<TD>" . nayta_operaatio($a['paivystys_id']);
    if ($take_ok) {
      echo "<TD><a href=\"$file?id=$a[id]&take=LAITE\">OTA TM</a>";
    } else {
      echo "<TD><a href=\"$file?id=$a[id]&release=LAITE\">VAPAUTA TM</a>";
    }
    echo "\n";
  }
  $sql =
    "SELECT id,tavara,tunniste,alue_id,paivystys_id
     FROM tavara
     WHERE jarjesto_id = $j_id AND hlo_id = $h_id
           AND (alue_id = 2 OR alue_id = " . s("alue") . ")
     ORDER BY tavara, tunniste";
  $handle = my_mysql_query($sql);
  while ($a = mysql_fetch_array($handle)) {
    $take_ok = 1; 
    if ($a['paivystys_id'] == s('paivystys'))
      $take_ok = 0;
    echo "<TR><TD><TD><TD>$a[tavara]<TD>$a[tunniste]"
      . "<TD>" . nayta_operaatio($a['paivystys_id']);
    if ($take_ok) {
      echo "<TD><a href=\"$file?id=$a[id]&take=TAVARA\">OTA TM</a>";
    } else {
      echo "<TD><a href=\"$file?id=$a[id]&release=TAVARA\">VAPAUTA TM</a>";
    }
    echo "\n";
  }
}

function nayta_releet_jarjesto($j_id,$j_jarjesto) {
  global $prefix;

  $j_n =
    ota_yksi("
SELECT COUNT(*)
FROM laite
WHERE jarjesto_id = $j_id
      AND (alue_id = 2 OR alue_id = " . s("alue") . ")
") + 
    ota_yksi("
SELECT COUNT(*)
FROM tavara
WHERE jarjesto_id = $j_id
      AND (alue_id = 2 OR alue_id = " . s("alue") . ")
");
  if ($j_n > 0) {
    # jrjestll on kamaa, nytetn.
    echo tr_vaalsin()
      . "<TD>$j_jarjesto";
    if ($j_id > 2) {
      echo "<TD><TD><TD><TD>"
	. "<TD><a href=\"$file?id=$j_id&take=JARJESTO\">OTA KAIKKI</a>"
	. "<br><a href=\"$file?id=$j_id&release=JARJESTO\">VAPAUTA KAIKKI</a>";
    }
    echo "\n";
    # ensin anonyymit releet 
    if (laske_releet_jarjesto_hlo($j_id, 0) > 0) {
      nayta_releet_jarjesto_hlo($j_id, 0);
    }
    # ... ja sitten vastuuhenkilittin
    $sql_h = "SELECT id,nimi FROM hlo ORDER BY nimi";
    $handle_h = my_mysql_query($sql_h);
    while ($h =  mysql_fetch_array($handle_h)) {
      $h_id = $h['id'];
      if (laske_releet_jarjesto_hlo($j_id, $h_id) > 0) {
	nayta_releet_jarjesto_hlo($j_id, $h_id);
      }
    }    
  }
}

echo "
<html>
<head>
 <title>ViHa - Operaation varustaminen</title>
</head>
" . body_bgcolor() . "
<h1>" . muotoile_operaatio() . ", operaation varustaminen</h1>
";

taktiset_linkit();

$id = get_nro_0('id');

# parametrointi toimii eri tavalla kuin yleens.
# take = ota, joka voi olla LAITE, TAVARA, HLO tai JARJESTO sen mukaan,
# halutaanko ottaa yksittinen laite tai tavara, kaikki tietyn yhdyshenkiln
# takana olevat laitteet ja tavarat vai kaikki koko jrjestn laitteet ja
# tavarat.
# release = vapauta toimii vastaavasti.

# show voi olla joko JARJESTO tai '', jolloin vastaavasti nytetn
# vain tietyn jrjestn (jarjesto_id) tai kaikki kalusto. XXX ei tehty viel

$take = get_txt('take');
$release = get_txt('release');
$show = get_nro('show');

$paivystys_se = s('paivystys');

# kuka vaan voi ottaa kalustoa alueeltaan - kytettvyyskysymys
switch ($take) {
 case '':
   break;
 case "LAITE":
   oltava_alueella($file,"laite",$id);
   break;
 case "TAVARA":
   oltava_alueella($file,"tavara",$id);
   break;
 case "JARJESTO":
   oltava_alueella($file,"jarjesto",$id);
   break;
 default:
   die("<p>Tuntematon parametri take=$take\n");
 }

if ($take == 'LAITE') {
  $p_id = ota_yksi("SELECT paivystys_id FROM laite WHERE id = $id");
  if ($p_id != $paivystys_se) {
    ilmoita_laite_jos_tarpeen($id);
    $now = date('Y-m-d H:i:s');
    $sql =
      "UPDATE laite
       SET paivystys_id=$paivystys_se, ryhma_id=1, ts='$now'
       WHERE id=$id";
    $result = my_mysql_query ($sql,true,true);
    $msg = "Otettu viestivline " . laite_tunniste($id);
    tehty($msg);
    taktinen_loki($msg);
  } else {
    echo "<p>Et voi ottaa viestivlinett joka kuuluu jo thn operaatioon.";
  }
}

if ($take == 'TAVARA') {
  $p_id = ota_yksi("SELECT paivystys_id FROM tavara WHERE id = $id");
  if ($p_id != $paivystys_se) {
    ilmoita_laite_jos_tarpeen($id);
    $now = date('Y-m-d H:i:s');
    $sql =
      "UPDATE tavara
       SET paivystys_id=$paivystys_se, ryhma_id=1, ts='$now'
       WHERE id=$id";
    $result = my_mysql_query ($sql,true,true);
    $msg = "Otettu tavara " . tavara_tunniste($id);
    tehty($msg);
    taktinen_loki($msg);
  } else {
    echo "<p>Et voi ottaa tavaraa joka kuuluu jo thn operaatioon.";
  }
}

if ($take == 'HLO') {
  die("<p>Nothing Happens."); # XXX
}

if ($take == 'JARJESTO') {
  $now = date('Y-m-d H:i:s');
  $sql =
    "UPDATE laite
     SET paivystys_id=$paivystys_se, ryhma_id=1, ts='$now'
     WHERE jarjesto_id=$id";
  $result = my_mysql_query ($sql,true,true);
  $sql =
    "UPDATE tavara
     SET paivystys_id=$paivystys_se, ryhma_id=1, ts='$now'
     WHERE jarjesto_id=$id";
  $result = my_mysql_query ($sql,true,true);
  $msg = "Otettu jrjestn " . jarjesto($id)
    . " kaikki kalusto thn operaatioon.";
  tehty($msg);
  taktinen_loki($msg);
}

if ($release == 'LAITE') {
  $p_id = ota_yksi("SELECT paivystys_id FROM laite WHERE id = $id");
  if ($p_id == $paivystys_se) {
    $now = date('Y-m-d H:i:s');
    $sql =
      "UPDATE laite
       SET paivystys_id=1, ryhma_id=1, ts='$now'
       WHERE id=$id";
    $result = my_mysql_query ($sql,true,true);
    $msg = "Vapautettu viestivline " . laite_tunniste($id);
    tehty($msg);
    taktinen_loki($msg);
  } else {
    echo
      "<p>Et voi vapauttaa viestivlinett joka ei kuulu thn operaatioon.";
  }
}

if ($release == 'TAVARA') {
  $p_id = ota_yksi("SELECT paivystys_id FROM tavara WHERE id = $id");
  if ($p_id == $paivystys_se) {
    $now = date('Y-m-d H:i:s');
    $sql =
      "UPDATE tavara
       SET paivystys_id=1, ryhma_id=1, ts='$now'
       WHERE id=$id";
    $result = my_mysql_query ($sql,true,true);
    $msg = "Vapautettu tavara " . tavara_tunniste($id);
    tehty($msg);
    taktinen_loki($msg);
  } else {
    echo
      "<p>Et voi vapauttaa kalustoa joka ei kuulu thn operaatioon.";
  }
}

if ($release == 'JARJESTO') {
  $now = date('Y-m-d H:i:s');
  $sql =
    "UPDATE laite
     SET paivystys_id=1, ryhma_id=1, ts='$now'
     WHERE jarjesto_id=$id";
  $result = my_mysql_query ($sql,true,true);
  $sql =
    "UPDATE tavara
     SET paivystys_id=1, ryhma_id=1, ts='$now'
     WHERE jarjesto_id=$id";
  $result = my_mysql_query ($sql,true,true);
  $msg = "Vapautettu jrjestn " . jarjesto($id) . " kaikki kalusto.";
  tehty($msg);
  taktinen_loki($msg);
}

# nytt generoidaan jrjestittin ja yhdyshenkilittin.

echo "<form action=\"\" method=\"GET\">\n";

echo "<input type=\"hidden\" name=\"id\" size=8 maxlength=8";
echo " value=\"$id\">\n";

echo "<p><TABLE BORDER=1>\n";
echo tr_vaalsin()
     . "<TH>Jrjest<TH>Yhdyshenkil<TH>Viestivline<BR>Tavara<TH>Tunniste"
     . "<TH>Operaatio\n";
$sql_j = "SELECT id,jarjesto,alue_id FROM jarjesto ORDER BY jarjesto";
$handle_j = my_mysql_query($sql_j);
while ($j =  mysql_fetch_array($handle_j)) {
  if (alue_nakyy($j['alue_id']))
    nayta_releet_jarjesto($j['id'],$j['jarjesto']);
}
echo "</TABLE>";

echo "</form>\n";

echo "
<p>Voit ottaa kalustoa tmn operaation kyttn klikkaamalla kohtaa OTA TM
(toimii mys muihin operaatioihin merkittyyn kalustoon).
<p>Kalustoa vapautetaan tmn operaation kytst klikkaamalla VAPAUTA TM.
Et voi vapauttaa kalustoa, joka ei kuulu thn operaatioon.
<p>Jrjestjen kohdalla olevat OTA KAIKKI ja VAPAUTA KAIKKI - linkit ottavat
ja vapauttavat koko jrjestn kaluston.
<p>Operaatio-sarakkeessa <font color=red>punaisella</font> on merkitty muut
operaatiot. Tmn operaation kalusto on merkitty
<font color=green>vihrell</font>. Vapaat on merkitty tll vrill.
";

#echo "
#<ul>Vaihtoehtoisia nkymi thn sivuun
#<li><a href=\"$file?show=\">
#  Nyt kaikki
# </a> (oletus)
#<li><a href=\"$file?show=1\">
#  Nyt vain henkilt jotka ovat vapaita tai toisessa operaatiossa
# </a> (kaikki otettavissa olevat)
#<li><a href=\"$file?show=2\">
#  Nyt vain henkilt jotka ovat vapaita
# </a>
#<li><a href=\"$file?show=3\">
#  Nyt vain henkilt jotka ovat tss operaatiossa
# </a> (kaikki vapautettavissa olevat)
#</ul>";

loppu();

?>
</body> 
</html>
<!-- RCS $Id: laite-oper.php,v 1.28 2009/10/05 11:12:31 riku Exp $ -->
